Tai senesnė versija. Naujausia versija – 3.0.0. Disk Usage Analyzer 3.0.0 · Išleista:
Diegimo failai 2.42.1
| Architektūra | Tipas | Kam | Failo dydis | Atsisiųsti | SHA256 |
|---|---|---|---|---|---|
| 64 bitų | ZIP → Nešiojamoji versija | — | — | github.com | VirusTotal |
| ARM64 | ZIP → Nešiojamoji versija | — | — | github.com | VirusTotal |
| 32 bitų | ZIP → Nešiojamoji versija | — | — | github.com | VirusTotal |
Nuoroda ir SHA256 paimti iš Windows Package Manager bendruomenės manifesto. Prieš paleisdami palyginkite atsisiųsto failo maišos reikšmę.
Laidos pastabos
*the same as 2.42, and:
Starting directories with a large amount of files, like 50k, now see a 5x speedup on macOS and Windows as bulk-reading is also done there. Note also that this is still a small absolute difference, 100ms vs 500ms, but a good demonstration of how much large trees with a lot of such directories will benefit by this, as these small absolute improvements accumulate.
Commit Statistics
- 3 commits contributed to the release.
- 1 day passed between releases.
- 0 commits were understood as conventional.
- 0 issues like '(#ID)' were seen in commit messages
Commit Details
view details
- Uncategorized
- Merge pull request #369 from tamird/macos-prepared-roots (3b1659e)
- Review (ffb2a2e)
- Reuse bulk metadata for macOS aggregation roots (d45a2f8)